#!/usr/bin/perl -w

# Copyright 2015, 2017 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.


use 5.010;
use strict;
use Math::BigRat;
use List::Util 'max','min';

use FindBin;
use lib $FindBin::Bin;
use MyRationals 'F';
use MyPrintwrap ':all';


my $depth = 20;

print "  % generated by tools/$FindBin::Script\n";
my $top = F($depth+2);

# HV(d,i) = [ F(i+1); F(i+2) + (d-i)*F(i+1) ];
# $i = 1 to $depth
sub HV_scaled {
  my ($i) = @_;
  my $p = F($i+1);
  my $q = F($i+2) + ($depth-$i)*F($i+1);
  $p = Math::BigRat->new($p) / $top;
  $q = Math::BigRat->new($q) / $top;
  $p = sprintf '%.5f', $p->as_float;
  $q = sprintf '%.5f', $q->as_float;
  return ($p, $q);
}

$Printwrap = 2;
printwrap("\\draw");
$Printwrap += 2;
my $join = '';
foreach my $i (1 .. $depth) {
  my ($p,$q) = HV_scaled($i);
  printwrap("$join($p,$q)");
  $join = '--';
}
foreach my $i (reverse 1 .. $depth) {
  my ($q,$p) = HV_scaled($i);
  printwrap("$join($p,$q)");
}
{
  my $o = Math::BigRat->new(1) / $top;
  $o = sprintf '%.5f', $o;
  printwrap("--($o,$o)")
}
printwrap("--cycle;\n");

print "  % end generated\n";
exit 0;
